==> owncloud-4.0.4.tgz: owncloud/settings/l10n/lb.php <==
<?php $TRANSLATIONS = array(
"OpenID Changed" => "OpenID huet geännert",
"Invalid request" => "Ongülteg Requête",
"Language changed" => "Sprooch huet geännert",
"__language_name__" => "__language_name__",
"Log" => "Log",
"More" => "Méi",
"Add your App" => "Setz deng App bei",
"Select an App" => "Wiel eng Applikatioun aus",
"-licensed" => "-Lizenséiert",
"by" => "vun",
"Documentation" => "Dokumentatioun",
"Managing Big Files" => "Grouss Fichieren verwalten",
"Ask a question" => "Stell eng Fro",
"Problems connecting to help database." => "Problemer sinn opgetrueden beim Versuch sech un d'Hëllef Datebank ze verbannen.",
"Go there manually." => "Gei manuell dohinner.",
"Answer" => "Äntwert",
"You use" => "Du benotz",
"of the available" => "vun den disponibelen",
"Desktop and Mobile Syncing Clients" => "Desktop an Mobile Syncing Clienten",
"Download" => "Download",
"Your password got changed" => "Däin Passwuert ass geännert ginn",
"Unable to change your password" => "Konnt däin Passwuert net änneren",
"Current password" => "Momentan 't Passwuert",
"New password" => "Neit Passwuert",
"show" => "weisen",
"Change password" => "Passwuert änneren",
"Email" => "Email",
"Your email address" => "Deng Email Adress",
"Fill in an email address to enable password recovery" => "Gëff eng Email Adress an fir d'Passwuert recovery ze erlaben",
"Language" => "Sprooch",
"Help translate" => "Hëllef iwwersetzen",
"use this address to connect to your ownCloud in your file manager" => "benotz dës Adress fir dech un deng ownCloud iwwert däin Datei Manager ze verbannen",
"Name" => "Numm",
"Password" => "Passwuert",
"Groups" => "Gruppen",
"Create" => "Erstellen",
"Default Quota" => "Standard Quota",
"Other" => "Aner",
"Quota" => "Quota",
"Delete" => "Läschen"
);

==> owncloud-4.5.7.tgz: owncloud/settings/l10n/lb.php <==
<?php $TRANSLATIONS = array(
"Unable to load list from App Store" => "Konnt Lescht net vum App Store lueden",
"Authentication error" => "Authentifikatioun's Fehler",
"Email saved" => "E-mail gespäichert",
"Invalid email" => "Ongülteg e-mail",
"OpenID Changed" => "OpenID huet geännert",
"Invalid request" => "Ongülteg Requête",
"Language changed" => "Sprooch huet geännert",
"Disable" => "Ofschalten",
"Enable" => "Aschalten",
"Saving..." => "Speicheren...",
"__language_name__" => "__language_name__",
"Security Warning" => "Sécherheets Warnung",
"Cron" => "Cron",
"Enable Share API" => "Share API aschalten",
"Allow apps to use the Share API" => "Erlab Apps d'Share API ze benotzen",
"Allow links" => "Links erlaben",
"Allow resharing" => "Resharing erlaben",
"Allow users to share with anyone" => "Useren erlaben mat egal wiem ze sharen",
"Allow users to only share with users in their groups" => "Useren nëmmen erlaben mat Useren aus hirer Grupp ze sharen",
"Log" => "Log",
"More" => "Méi",
"Add your App" => "Setz deng App bei",
"Select an App" => "Wiel eng Applikatioun aus",
"See application page at apps.owncloud.com" => "Kuck dir d'Applicatioun's Säit op apps.owncloud.com un",
"Documentation" => "Dokumentatioun",
"Managing Big Files" => "Grouss Fichieren verwalten",
"Ask a question" => "Stell eng Fro",
"Problems connecting to help database." => "Problemer sinn opgetrueden beim Versuch sech un d'Hëllef Datebank ze verbannen.",
"Go there manually." => "Gei manuell dohinner.",
"Answer" => "Äntwert",
"Desktop and Mobile Syncing Clients" => "Desktop an Mobile Syncing Clienten",
"Download" => "Download",
"Unable to change your password" => "Konnt däin Passwuert net änneren",
"Current password" => "Momentan 't Passwuert",
"New password" => "Neit Passwuert",
"show" => "weisen",
"Change password" => "Passwuert änneren",
"Email" => "Email",
"Your email address" => "Deng Email Adress",
"Fill in an email address to enable password recovery" => "Gëff eng Email Adress an fir d'Passwuert recovery ze erlaben",
"Language" => "Sprooch",
"Help translate" => "Hëllef iwwersetzen",
"use this address to connect to your ownCloud in your file manager" => "benotz dës Adress fir dech un deng ownCloud iwwert däin Datei Manager ze verbannen",
"Name" => "Numm",
"Password" => "Passwuert",
"Groups" => "Gruppen",
"Create" => "Erstellen",
"Default Quota" => "Standard Quota",
"Other" => "Aner",
"Group Admin" => "Gruppen Admin",
"Quota" => "Quota",
"Delete" => "Läschen"
);
